"""Common filenames and locations for topographic data, meshes and outputs.

All filenames are given without extension
"""

from os import sep, environ, getenv, getcwd, umask
from os.path import expanduser, basename, join
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon, number_mesh_triangles
import sys
from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
from time import localtime, strftime, gmtime
from anuga.utilities.system_tools import get_user_name, get_host_name

codename = 'project_grad.py' # FIXME can be obtained automatically as __file__

home = join(getenv('INUNDATIONHOME'), 'data') # Location of Data   
user = get_user_name()
host = get_host_name()
#needed when running using mpirun, mpirun doesn't inherit umask from .bashrc
umask(002)

#Making assumptions about the location of scenario data
state = 'western_australia'
scenario_name = 'onslow'
scenario = 'onslow_tsunami_scenario_2006'

#time stuff
time = strftime('%Y%m%d_%H%M%S',gmtime()) #gets time for new dir
build_time = time+'_build'
run_time = time+'_run'

#tide = 0.0 # MSL
tide = 1.5 # HAT 
#tide = -1.5 # LAT

#Maybe will try to make project a class to allow these parameters to be passed in.
alpha = 0.1
friction = 0.01
finaltime = 40000
starttime = 3600 # Action starts around 9000
#setup='final'
setup = 'trial'
which_data = 'original'
#which_data = 'revised'
boundary_event = 'onslow'

boundary_event = 'exmouth'
#boundary_event = 'onslow'
#boundary_event = 'dampier'

if setup =='trial':
    print'trial'
    res_factor=10
    time_thinning=48
    yieldstep=240
if setup =='basic': 
    print'basic'
    res_factor=4
    time_thinning=12
    yieldstep=120
if setup =='final': 
    print'final'
    res_factor=1.0
    time_thinning=4
    yieldstep=60

anuga_dir = join(home, state, scenario, 'anuga')

topographies_in_dir = join(anuga_dir, 'topographies')

topographies_dir = join(anuga_dir, 'topographies') # Output dir for ANUGA

if boundary_event =='dampier':
    boundaries_name = 'onslow_3854_17042007' #Dampier gun
    boundaries_in_dir = join(anuga_dir,'boundaries','urs','dampier','1_10000')

if boundary_event=='onslow':
    boundaries_name = 'onslow_3859_16052007' #onslow_hedland_broome gun
    boundaries_in_dir = join(anuga_dir,'boundaries','urs','onslow_hedland_broome','1_10000')
    
if boundary_event=='exmouth':
    boundaries_name = 'onslow_3103_18052007' #exmouth gun
    boundaries_in_dir = join(anuga_dir,'boundaries','urs','exmouth','1_10000')

dir_comment='_'+setup+'_'+str(tide)+'_'+\
             str(user)+'_'+boundary_event+which_data


# elevation data filenames

if which_data == 'original':
    ascii_grid_filenames = ['onslow_onshore_20m_dli', 'onslow_islands_dted2']
    point_filenames = ['onslow_offshore_points', 'onslow_coast']

if which_data == 'revised':
    ascii_grid_filenames = ['revised_onshore_20m_dli', 'onslow_islands_dted2']
    point_filenames = ['onslow_offshore_points', 'revised_coastline',
                       'beach_survey', 'ONS16FINAL', 'ONS17FINAL', 'ONS18FINAL' ]

# final topo name
combined_name ='onslow_combined_elevation_grad'
combined_small_name = 'onslow_combined_elevation_grad'


# Convert topo file locations into absolute pathnames
for filename_list in [ascii_grid_filenames, point_filenames]:
    for i, filename in enumerate(filename_list):
        filename_list[i] = join(topographies_in_dir, filename)

#final topo files
combined_dir_name = join(topographies_dir, combined_name)
combined_small_dir_name = join(topographies_dir, combined_small_name)

mesh_dir = join(anuga_dir, 'meshes')
mesh_name = join(mesh_dir, scenario_name)

polygons_dir = join(anuga_dir, 'polygons') # Created with ArcGIS (csv files)
tide_dir = join(anuga_dir, 'tide_data')

#output locations
output_dir = join(anuga_dir, 'outputs')+sep
output_build_time_dir = output_dir+build_time+sep
output_run_time_dir = output_dir +run_time+dir_comment+sep
output_run_time_dir_name = output_run_time_dir + scenario_name  #Used by post processing

#gauges
gauges_dir = join(anuga_dir,'gauges')
gauge_name = 'gauge_location_onslow.csv'
gauges_dir_name = gauges_dir + gauge_name

#buildings_filename = gauges_dir + 'Onslow_res_Project.csv'
#buildings_filename_out = 'Onslow_res_Project_modified.csv'

# for ferret2sww
south = degminsec2decimal_degrees(-20,30,0)
north = degminsec2decimal_degrees(-17,10,0)
west = degminsec2decimal_degrees(117,00,0)
east = degminsec2decimal_degrees(120,00,0)

# region to export (used from export_results.py)
e_min_area = 300000   # Eastings min
e_max_area = 310000
n_min_area = 7600000
n_max_area = 7610000
                
#FIXME (Ole): It is bad to read in polygons in project.py. If a file does not exist
#project.py cannot be imported

# Bounding polygon
#bounding_polygon = read_polygon(join(polygons_dir, 'domain.csv'))
#res_bounding_polygon = 500000*res_factor

# Interior regions
interior_regions_and_resolutions = {
    'inner_region': 5000,
    'region_50m': 50000,
    'onslow': 500}

# Domain
boundary_tags = {'back': [1, 2, 3, 4, 5],   
                 'side': [0, 6],
                 'ocean': [7, 8, 9, 10, 11]}

interior_regions = [] # Consider using dictionary for mesh interface.
for area_name in interior_regions_and_resolutions.keys():
    file_name = join(polygons_dir, area_name + '.csv')
    
    print 'Reading polygon from', file_name 
    polygon = read_polygon(file_name)
    base_resolution = interior_regions_and_resolutions[area_name]
    
    interior_regions.append([polygon, base_resolution*res_factor])

trigs_min = number_mesh_triangles(interior_regions,
                                  bounding_polygon,
                                  res_bounding_polygon)

onshore_polygon = read_polygon(join(topographies_in_dir,
                                    'InitialCondition_points.csv'))
